# Changelog

All notable changes to this package will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0).






## [0.91.0] - 2025-09-22

### 🚀 Features

- d74568f npm/runtime: Revert back to CJS (#13999) (Boshen)
- 36bbba8 npm/runtime: Convert to ES modules (#13874) (Boshen)

### 💼 Other

- fb347da crates: V0.91.0 (#13961) (Boshen)



## [0.90.0] - 2025-09-18

### 🚀 Features

- b52389a node: Bump `engines` field to require Node.js 20.19.0+ for ESM support (#13879) (Copilot)





























# Changelog

All notable changes to this package will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project does not adhere to [Semantic Versioning](https://semver.org/spec/v2.0.0.html) until v1.0.0.

## [0.52.0] - 2025-02-21

### Features

- 6c24357 npm/runtime: Add `decorateMetadata` helper function (#9189) (Dunqing)

## [0.51.0] - 2025-02-15

### Bug Fixes

- 5f15605 npm/runtime: Incorrect file paths in `exports` (#9069) (Dunqing)

## [0.50.0] - 2025-02-12

### Features

- b89f691 npm/runtime: Add `decorate` and `decorateParam` helper functions (#8971) (Dunqing)

## [0.49.0] - 2025-02-10

### Features

- 951b2d5 npm/runtime: Add `@oxc-project/runtime` package (#8595) (Boshen)

